@@ -4,9 +4,10 @@ from __future__ import print_function, division, unicode_literals, absolute_impo
 executable = "aim"
 
 from abimkdocs.variables import ValueWithUnit, MultipleValue, Range
+#from abipy.abio.abivar_database.variables import ValueWithUnit, MultipleValue, Range, ValueWithConditions
 ValueWithConditions = dict
-
 Variable=dict
+
 variables = [
 Variable(
     abivarname="atom@aim",
@@ -16,7 +17,8 @@ Variable(
     dimensions="scalar",
     defaultval=1,
     mnemonics="index of ATOM",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Index of the investigated atom.
 """,
 ),
@@ -29,7 +31,8 @@ Variable(
     dimensions="scalar",
     defaultval=1.0,
     mnemonics="bader ATomic RADius",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 A first estimation of the Bader radius (not too important - it is used only
 two times)
 """,
@@ -43,7 +46,8 @@ Variable(
     dimensions="scalar",
     defaultval=0.98,
     mnemonics="COeFFicient 1",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 See the input variable [[ratmin@aim]].
 """,
 ),
@@ -56,7 +60,8 @@ Variable(
     dimensions="scalar",
     defaultval=0.95,
     mnemonics="COeFFicient 2",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 See the input variable [[ratmin@aim]].
 """,
 ),
@@ -69,7 +74,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="computation of CRITical points",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Drives the computation of critical points.
 
   * [0] not
@@ -103,7 +109,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="electronic DENsity OUTput",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Output of the electronic density. The specification of the line (plane) in the
 real space must be given in the input variable [[vpts@aim]] and grid in
 [[ngrid@aim]]. It is also possible to get only the valence density or the core
@@ -123,7 +130,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="Density or Laplacian TYP output",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Specification of the contribution of the electronic density corresponding to
 the density and/or laplacian output (see [[denout@aim]] and [[lapout@aim]])
 
@@ -141,10 +149,11 @@ Variable(
     dimensions="scalar",
     defaultval="1.d-2",
     mnemonics="DPCLIM",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 If two "numerically different" critical points are separated by less than
-**dpclim** , they are considered to be the same critical point. This often
-happens because of numerical inaccuracies : one CP might be "seen" by two
+**dpclim**, they are considered to be the same critical point. This often
+happens because of numerical inaccuracies: one CP might be "seen" by two
 different finite elements. The default should be OK when the ecut is quite
 large, on the order of 60 Hartree. For less accurate calculations of the
 density, increase the default value to 5.d-2, let's say.
@@ -159,7 +168,8 @@ Variable(
     dimensions=[3],
     defaultval="3*0.0",
     mnemonics="FOLlow DEParture",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Needed in the case [[aim:follow]]=1 only. Defines the starting point.
 """,
 ),
@@ -172,7 +182,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="FOLLOW the gradient path",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Follow the gradient path to the corresponding atom starting from the position
 specified in the input variable [[aim:foldep]].
 """,
@@ -186,7 +197,8 @@ Variable(
     dimensions="scalar",
     defaultval=0.5,
     mnemonics="FOLlow STeP",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 The first step for following the gradient path.
 """,
 ),
@@ -199,7 +211,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="GraPhic output for the bader SURFace",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Drives the graphic output (gnuplot script) of the irreducible part of the
 calculated Bader surface.
 
@@ -216,7 +229,8 @@ Variable(
     dimensions="scalar",
     defaultval=100,
     mnemonics="numer of INtegration PoinTs",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Number of radial points used for integration of the Bader charge (not too
 sensitive).
 """,
@@ -230,7 +244,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="Integration of the charge density RHO",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Drives the integration of the charge of the Bader atom.
 
   * 0, not calculated
@@ -246,7 +261,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="Integration of the VOLume",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Drives the integration of the volume of the Bader atom.
 
   * 0, not calculated
@@ -262,7 +278,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="electronic density LAPlacian OUTput",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Output of the laplacian of electronic density. The specification of the line
 (plane) in the real space must be given in the input variable [[aim:vpts]] and
 grid in [[aim:ngrid]]. It is also possible to get only the valence density or
@@ -282,7 +299,8 @@ Variable(
     dimensions="scalar",
     defaultval="1.d-12",
     mnemonics="Low GRADient criterion",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 The search for one particular CP is decided to be successful when either the
 norm of the gradient of the electron density is smaller than **lgrad** or when
 the length of the planned search step is smaller than [[aim:lstep]]. If the
@@ -302,7 +320,8 @@ Variable(
     dimensions="scalar",
     defaultval="1.d-5",
     mnemonics="Low GRADient criterion 2",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Determines the criterion for deciding that a CP has been found. See
 [[aim:lgrad]] for more details.
 """,
@@ -316,7 +335,8 @@ Variable(
     dimensions="scalar",
     defaultval="1.d-10",
     mnemonics="Length of the planned search STEP",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Determines the criterion for deciding a CP has been found. See [[aim:lgrad]]
 for more details.
 """,
@@ -330,7 +350,8 @@ Variable(
     dimensions="scalar",
     defaultval="1.d-5",
     mnemonics="Length of the planned search STEP 2",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Determines the criterion for deciding that a CP has been found. See
 [[aim:lgrad]] for more details.
 """,
@@ -344,7 +365,8 @@ Variable(
     dimensions="scalar",
     defaultval=10.0,
     mnemonics="MAXimal ATomic Distance",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Atoms within this maximal distance are considered in order to start the search
 of a CP.
 
@@ -362,7 +384,8 @@ Variable(
     dimensions="scalar",
     defaultval=5.0,
     mnemonics="MAXimal CP Distance",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 The CPs are searched for within this maximal distance.
 
 Note that the supercell, determined by [[aim:nsa]], [[aim:nsb]], and
@@ -379,7 +402,8 @@ Variable(
     dimensions=[2],
     defaultval="2*30",
     mnemonics="Number of GRID points",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Defines the grid in real space, for the density and laplacian outputs,
 governed by [[aim:denout]] and [[aim:lapout]].
 """,
@@ -393,7 +417,8 @@ Variable(
     dimensions="scalar",
     defaultval=48,
     mnemonics="Number of PHI angle",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 With [[aim:ntheta]], this variable defines the angular grid for the
 integration within the Bader volume, in particular, the number of phi angles,
 to be used between [[aim:phimin]] and [[aim:phimax]]. When the difference
@@ -411,9 +436,10 @@ Variable(
     dimensions="scalar",
     defaultval=3,
     mnemonics="Number of Supercell points in direction A",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 These variables define a "supercell", from the primitive cell repeated along
-each primitive direction. This supercell is build as follows :
+each primitive direction. This supercell is build as follows:
 
 
 
@@ -437,9 +463,10 @@ Variable(
     dimensions="scalar",
     defaultval=3,
     mnemonics="Number of Supercell points in direction B",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 These variables define a "supercell", from the primitive cell repeated along
-each primitive direction. This supercell is build as follows :
+each primitive direction. This supercell is build as follows:
 
 
 
@@ -463,9 +490,10 @@ Variable(
     dimensions="scalar",
     defaultval=3,
     mnemonics="Number of Supercell points in direction C",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 These variables define a "supercell", from the primitive cell repeated along
-each primitive direction. This supercell is build as follows :
+each primitive direction. This supercell is build as follows:
 
 
 
@@ -489,7 +517,8 @@ Variable(
     dimensions="scalar",
     defaultval=32,
     mnemonics="Number of THETA angles",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 With [[aim:nphi]], this variable defines the angular grid for the integration
 within the Bader volume, in particular, the number of theta angles, to be used
 between [[aim:thetamin]] and [[aim:thetamax]]. When the difference between
@@ -506,7 +535,8 @@ Variable(
     dimensions="scalar",
     defaultval=2.0,
     mnemonics="PHI MAXimal angle",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Angular limits of integration of the Bader volume for the phi variables. The
 number of integration points is given by [[aim:nphi]]. The range of
 integration can be decreased if there are symmetry reasons for doing this.
@@ -521,7 +551,8 @@ Variable(
     dimensions="scalar",
     defaultval=0.0,
     mnemonics="PHI MINimal angle",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Angular limits of integration of the Bader volume for the phi variables. The
 number of integration points is given by [[aim:nphi]]. The range of
 integration can be decreased if there are symmetry reasons for doing this.
@@ -536,7 +567,8 @@ Variable(
     dimensions="scalar",
     defaultval=0.05,
     mnemonics="RADial STeP",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 The length of the first step in the search of the exact Bader radius.
 """,
 ),
@@ -549,7 +581,8 @@ Variable(
     dimensions="scalar",
     defaultval=1.0,
     mnemonics="Radius Atomic MINimal",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 The first estimation of the smallest radius of the basin of the atom (the
 distance at which the procedure that follows the gradient path announces that
 the gradient path finishes in the corresponding atom) This parameter is very
@@ -570,7 +603,8 @@ Variable(
     dimensions=[2],
     defaultval="2*0.0",
     mnemonics="Radius SURface DIRection",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 In the case [[aim:rsurf]]=1, gives the direction (angular coordinates
 theta,phi) along which the radius of the Bader surface is to be determined.
 """,
@@ -584,7 +618,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="computation of the Radius bader SURFace",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Drive the computation of the radius of the Bader surface for the angles
 specified in the input variable [[aim:rsurdir]]
 
@@ -601,7 +636,8 @@ Variable(
     dimensions=[3],
     defaultval="1.0 1.0 1.0",
     mnemonics="SCALing of the cartesian coordinates",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 SCALing of the cartesian coordinates.
 """,
 ),
@@ -614,7 +650,8 @@ Variable(
     dimensions="scalar",
     defaultval=0,
     mnemonics="computation of the bader SURFace",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Drive the computation of the full Bader surface.
 
   * 0, not calculated
@@ -628,9 +665,10 @@ Variable(
     vartype="real",
     topics=['Bader_basic'],
     dimensions="scalar",
-    defaultval="$\pi$",
+    defaultval=r"$\pi$",
     mnemonics="THETA MAXimal angle",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Angular limits of integration of the Bader volume for the theta variables. The
 number of integration points is given by [[aim:ntheta]]. The range of
 integration can be decreased if there are symmetry reasons for doing this.
@@ -645,7 +683,8 @@ Variable(
     dimensions="scalar",
     defaultval=0.0,
     mnemonics="THETA MINimal angle",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Angular limits of integration of the Bader volume for the theta variables. The
 number of integration points is given by [[aim:ntheta]]. The range of
 integration can be decreased if there are symmetry reasons for doing this.
@@ -661,7 +700,8 @@ Variable(
     defaultval="6*0.0",
     mnemonics="Vectors defining the PoinTS of the surface",
     commentdims="6 for 1D, 9 for 2D",
-    text="""
+    added_in_version="before_v9",
+    text=r"""
 Basic vectors of the line or rectangle in real space, defining the points for
 which the density or laplacian will be computed, thanks to [[aim:denout]] or
 [[aim:lapout]]
