@@ -184,6 +184,24 @@ symmetry of the material. The directions of the requested components are specifi
 """,
 ),
 
+Variable(
+    abivarname="prtlincompmatrixelements@optic",
+    varset="optic",
+    vartype="integer",
+    topics=['Optic_basic'],
+    dimensions="scalar",
+    defaultval=0,
+    mnemonics="PRinT the LINear COMPonent of the dielectric tensor's MATRIX ELEMENTS",
+    added_in_version="v9.5",
+    text=r"""
+If set to 1, the matrix elements, the renormalized (but unshifted) Kohn-Sham eigenvalues,
+the occupations and the kpts weights are all printed out in the ‘_OPTIC.nc’ file
+generated by the optic script. The matrix elements are the ones used to build the linear
+components of the dielectric tensor. Useful for post processing of matrix elements or
+rebuild the linear components of the dielectric tensor in an external script.
+""",
+),
+
 Variable(
     abivarname="linel_comp@optic",
     varset="optic",
