@@ -33,6 +33,7 @@
 # ==                                                                  ==
 # ==                              M. Torrent - 09/2012, rev. 06/2013  ==
 # ======================================================================
+from __future__ import print_function
 
 import os
 import re
@@ -309,16 +310,16 @@ IGNORES_FILES = ["interfaces_"]
 # ---------------------------------------------------------------------------
 
 if (len(sys.argv)==1) or ("--help" in sys.argv):
-  print "Usage:"
-  print "  check_datatypes [--all] [--unused] [--suggest] [--ok]"
-  print "                  [--only module_name] [--autofix]"
-  print "  --unused  : list unused datatypes"
-  print "  --suggest : list suggested changes in use statements"
-  print "  --ok      : list correctly used datatypes"
-  print "  --all     : list all (default)"
-  print "  --only    : treat only module named module_name"
-  print "  --autofix : automatically repair errors in src files"
-  print "  Only one option in (unused, suggest, ok, all) allowed !"
+  print ("Usage:")
+  print ("  check_datatypes [--all] [--unused] [--suggest] [--ok]")
+  print ("                  [--only module_name] [--autofix]")
+  print ("  --unused  : list unused datatypes")
+  print ("  --suggest : list suggested changes in use statements")
+  print ("  --ok      : list correctly used datatypes")
+  print ("  --all     : list all (default)")
+  print ("  --only    : treat only module named module_name")
+  print ("  --autofix : automatically repair errors in src files")
+  print ("  Only one option in (unused, suggest, ok, all) allowed !")
   exit()
 
 noselection=((not "--unused" in sys.argv) and (not "--suggest" in sys.argv) and \
@@ -337,12 +338,12 @@ else:
 
 # ---------------------------------------------------------------------------
 
-print
-print '---------------------------------------------------------------------'
-print ' Looking for "use module" statements in ABINIT Fortran source files. '
-print '  - check if they are useful                                         '
-print '  - list missing "only" statements                                   '
-print '---------------------------------------------------------------------\n'
+print()
+print( '---------------------------------------------------------------------')
+print( ' Looking for "use module" statements in ABINIT Fortran source files. ')
+print( '  - check if they are useful                                         ')
+print( '  - list missing "only" statements                                   ')
+print( '---------------------------------------------------------------------\n')
 
 re_srcfile = re.compile("\.([Ff]|[Ff]90)$")
 file_total_count=0
@@ -353,7 +354,8 @@ for (root, dirs, files) in os.walk("./src"):
     if (re_srcfile.search(src)):
       file_total_count+=1
       filename=os.path.join(root,src)
-      src_data=file(filename).readlines()
+      with open(filename, "r") as fh:
+        src_data = fh.readlines()
 
 #     Ignore some files
       ignore=False
@@ -428,7 +430,7 @@ for (root, dirs, files) in os.walk("./src"):
               if (len(list_all))==0:
                 module_unused=True
                 if do_unused and not autofix:
-                  print "File %s: module %s present but not used !" % (filename,module)
+                  print ("File %s: module %s present but not used !" % (filename,module))
 
 #             Second case: module used - suggest "only" statement
               else:
@@ -444,30 +446,30 @@ for (root, dirs, files) in os.walk("./src"):
                   sugg_only_string+=item;len_cur=len_cur+len(item)
                 if missing_count==0:
                   if do_ok:
-                    print "File %s: module %s correctly used !" % (filename,module)
+                    print ("File %s: module %s correctly used !" % (filename,module))
                 else:
                   if do_suggest and not autofix:
-                    print "File %s: module %s, suggested use:" % (filename,module)
-                    print "  * use "+module+", only : "+sugg_only_string
+                    print ("File %s: module %s, suggested use:" % (filename,module))
+                    print ("  * use "+module+", only : "+sugg_only_string)
                     if multiple_sub:
-                      print "  * WARNING: several subroutines/functions in file !"
+                      print ("  * WARNING: several subroutines/functions in file !")
 
 #             === AUTOFIX ===
               if autofix:
                 if (module_unused and do_unused) or (missing_count>0 and do_suggest):
-                  print "==> FIXING file %s" %(filename)
+                  print ("==> FIXING file %s" %(filename))
                   if module_unused and do_unused:
-                    print '    ELIMINATING module %s !' % (module)
+                    print ('    ELIMINATING module %s !' % (module))
                   if missing_count>0 and do_suggest:
-                    print '    REWRITING "use module" line for %s !' % (module)
+                    print ('    REWRITING "use module" line for %s !' % (module))
                     if multiple_sub:
-                      print '    WARNING: several subroutines/functions in file (check it MANUALLY) !'
+                      print ('    WARNING: several subroutines/functions in file (check it MANUALLY) !')
 #                 Open a temporary file for writing
                   ErrorEncountered=False
                   filenametmp=filename+'.tmp'
                   try: filout=open(filenametmp,'w')
                   except:
-                    print 'File %s, error: could not open tmp file !' % (filename)
+                    print ('File %s, error: could not open tmp file !' % (filename))
                     ErrorEncountered=True
                   if not ErrorEncountered:
 #                   Loop over lines in the file
@@ -482,14 +484,16 @@ for (root, dirs, files) in os.walk("./src"):
                         if do_write_line==2: newline=" use "+module+", only : "+sugg_only_string+"\n"
                         try: filout.write(newline)
                         except:
-                          print 'File %s, error: could not write into tmp file !' % (filename)
+                          print ('File %s, error: could not write into tmp file !' % (filename))
                           ErrorEncountered=True;break
                   filout.close()
 #                 Replace current file by temporary file
                   if not ErrorEncountered:
-                    try: os.system('mv -f '+filenametmp+' '+filename)
-                    except: print 'File %s, error: could not move tmp file !' % (filename)
+                    try: 
+                        os.system('mv -f '+filenametmp+' '+filename)
+                    except: 
+                        print ('File %s, error: could not move tmp file !' % (filename))
 
 #Final printing
-print "--------------------------------------"
-print "Done !, %s files have been explored." % (file_total_count)
+print ("--------------------------------------")
+print ("Done !, %s files have been explored." % (file_total_count))
