@@ -19,7 +19,7 @@ __all__ = ['FanFile']
 class FanFile(EpcFile):
     
     def read_nc(self, fname=None):
-        """Open the EIG2D.nc file and read it."""
+        """Open the FAN.nc file and read it."""
         fname = fname if fname else self.fname
 
         super(FanFile, self).read_nc(fname)
