@@ -26,10 +26,8 @@ except:
 
 from numpy import *
 
-
-
 #----------------------------------------------------------------#
-#-----------WINDOWS-RADIAL DISTRIBUTION FUNCTION-----------------#
+#---------------------WINDOWS-TOPOLOGY---------------------------#
 #----------------------------------------------------------------#
 class winRDF(QtGui.QWidget):
 
@@ -185,7 +183,7 @@ class winRDF(QtGui.QWidget):
                 self.layout.addWidget(self.pbClose , 8, 0, 1, 1, QtCore.Qt.AlignRight)
                 self.layout.addWidget(self.pbDraw  , 8, 1, 1, 1, QtCore.Qt.AlignCenter)
             
-            elif ntypat == 2:
+            else:
             
                 self.layout.addWidget(self.mode    , 1, 0, 1, 1, QtCore.Qt.AlignRight)
                 self.layout.addWidget(self.sbm     , 1, 1, 1, 1, QtCore.Qt.AlignCenter)
@@ -223,7 +221,7 @@ class winRDF(QtGui.QWidget):
                 self.layout.addWidget(self.pbClose , 7, 0, 1, 1, QtCore.Qt.AlignRight)
                 self.layout.addWidget(self.pbDraw  , 7, 1, 1, 1, QtCore.Qt.AlignCenter)
             
-            elif ntypat == 2:
+            else:
             
                 self.layout.addWidget(self.mode    , 1, 0, 1, 1, QtCore.Qt.AlignRight)
                 self.layout.addWidget(self.sbm     , 1, 1, 1, 1, QtCore.Qt.AlignCenter)
@@ -260,7 +258,7 @@ class winRDF(QtGui.QWidget):
                 self.layout.addWidget(self.pbClose , 7, 0, 1, 1, QtCore.Qt.AlignRight)
                 self.layout.addWidget(self.pbDraw  , 7, 1, 1, 1, QtCore.Qt.AlignCenter)
 
-            elif ntypat == 2:
+            else:
 
                 self.layout.addWidget(self.mode    , 1, 0, 1, 1, QtCore.Qt.AlignRight)
                 self.layout.addWidget(self.sbm     , 1, 1, 1, 1, QtCore.Qt.AlignCenter)
@@ -573,13 +571,13 @@ class winRDF(QtGui.QWidget):
             self.sbdt.setMaximum(5)
             self.sbdt.setFixedWidth(70)
 
-            self.lbl7 = QtGui.QLabel("neighbors :", self)
-            self.lbl7.setFixedWidth(71)
-            self.sbn = QtGui.QSpinBox()
-            self.sbn.setSingleStep(1)
-            self.sbn.setValue(2)
-            self.sbn.setMinimum(2)
-            self.sbn.setMaximum(nat-1)
+            self.lbl7 = QtGui.QLabel("cutoff :", self)
+            self.lbl7.setFixedWidth(60)
+            self.sbn = QtGui.QDoubleSpinBox()
+            self.sbn.setSingleStep(0.1)
+            self.sbn.setValue(4)
+            self.sbn.setMinimum(1)
+            self.sbn.setMaximum(20)
             self.sbn.setFixedWidth(70)
 
         elif mode == 'NDF':
