@@ -10,30 +10,30 @@ keywords = [
 
 #: List of input files
 inp_files = [
-"t00.in",
-"t01.in",
-"t02.in",
-"t03.in",
-"t04.in",
-"t05.in",
-"t06.in",
-"t07.in",
-"t08.in",
-"t09.in",
-"t11.in",
-"t12.in",
-"t14.in",
-"t16.in",
-"t17.in",
-"t19.in",
-"t20.in",
-"t21.in",
-"t23.in",
-"t24.in",
-"t25.in",
-"t26.in",
-"t27.in",
-"t28.in",
-"t29.in",
-"t30.in",
+"t00.abi",
+"t01.abi",
+"t02.abi",
+"t03.abi",
+"t04.abi",
+"t05.abi",
+"t06.abi",
+"t07.abi",
+"t08.abi",
+"t09.abi",
+"t11.abi",
+"t12.abi",
+"t14.abi",
+"t16.abi",
+"t17.abi",
+"t19.abi",
+"t20.abi",
+"t21.abi",
+"t23.abi",
+"t24.abi",
+"t25.abi",
+"t26.abi",
+"t27.abi",
+"t28.abi",
+"t29.abi",
+"t30.abi",
 ]
